==> ehome-rcm-0.15.2.tgz: package/es/form-view/customFields/CustomerSelector/index.js <==
import "antd-mobile/es/modal/style";
import _Modal from "antd-mobile/es/modal";
import "antd-mobile/es/icon/style";
import _Icon from "antd-mobile/es/icon";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { return function () { var Super = _getPrototypeOf(Derived), result; if (_isNativeReflectConstruct()) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { PureComponent, Component } from 'react';
import PropTypes from 'prop-types';

var CustomerSelector = /*#__PURE__*/function (_ref) {
  _inherits(CustomerSelector, _ref);

  var _super = _createSuper(CustomerSelector);

  function CustomerSelector(props) {
    var _this;

    _classCallCheck(this, CustomerSelector);

    _this = _super.call(this, props);

    _defineProperty(_assertThisInitialized(_this), "clickField", function () {
      var scrollTop = document.body.scrollTop || document.documentElement.scrollTop;
      var rootElement = document.getElementById('root'); // 使 root 脱离文档流

      rootElement.classList.add('dialog-open'); // 把脱离文档流的 root 拉上去，否则页面会回到顶部！

      rootElement.style.top = "".concat(-scrollTop, "px");

      _this.setState({
        visible: true,
        bodyScrollTop: scrollTop
      });
    });

    _defineProperty(_assertThisInitialized(_this), "closeModal", function (e) {
      e.stopPropagation();
      var bodyScrollTop = _this.state.bodyScrollTop;
      var rootElement = document.getElementById('root');
      rootElement.classList.remove('dialog-open'); // 滚回到老地方

      document.body.scrollTop = bodyScrollTop;
      document.documentElement.scrollTop = bodyScrollTop;

      _this.setState({
        visible: false
      });
    });

    _this.state = {
      visible: false
    };
    return _this;
  }

  _createClass(CustomerSelector, [{
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      // root回到文档流中
      var rootElement = document.getElementById('root');
      rootElement.classList.remove('dialog-open');
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          field = _this$props.field,
          layoutType = _this$props.layoutType,
          commonPrefixCls = _this$props.commonPrefixCls,
          labelWidth = _this$props.labelWidth,
          nullDisplayType = _this$props.nullDisplayType; // eslint-disable-next-line prefer-const

      var visible = this.state.visible;
      var fieldName = field.fieldName,
          _field$fieldValue = field.fieldValue,
          fieldValue = _field$fieldValue === void 0 ? '{}' : _field$fieldValue;
      fieldValue = JSON.parse(fieldValue);
      var prefixCls = 'eh-field-view-checkbox';
      var modalPrefixCls = "".concat(prefixCls, "-modal");
      prefixCls += layoutType === 0 ? '-hor' : '-ver';
      var hidden = nullDisplayType === 1 && !fieldValue.name.length;
      return hidden ? null : /*#__PURE__*/React.createElement("div", {
        className: prefixCls,
        onClick: !fieldValue.name ? null : this.clickField
      }, /*#__PURE__*/React.createElement("div", {
        className: "".concat(commonPrefixCls, "-name"),
        style: {
          width: labelWidth
        }
      }, fieldName), /*#__PURE__*/React.createElement("div", {
        className: "".concat(commonPrefixCls, "-value ").concat(prefixCls, "-value")
      }, /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-info")
      }, /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-info-text")
      }, fieldValue.name || '无'), /*#__PURE__*/React.createElement("i", {
        className: "".concat(prefixCls, "-icon eh-iconfont")
      }, "\uE773"))), /*#__PURE__*/React.createElement(_Modal, {
        popup: true,
        visible: visible,
        onClose: this.closeModal,
        animationType: "slide-up"
      }, /*#__PURE__*/React.createElement("div", {
        className: modalPrefixCls
      }, /*#__PURE__*/React.createElement("div", {
        className: "".concat(modalPrefixCls, "-header")
      }, /*#__PURE__*/React.createElement(_Icon, {
        type: "cross",
        onClick: this.closeModal
      }), /*#__PURE__*/React.createElement("span", {
        className: "".concat(modalPrefixCls, "-header-text")
      }, fieldName)), /*#__PURE__*/React.createElement("div", {
        className: "".concat(modalPrefixCls, "-content")
      }, /*#__PURE__*/React.createElement("div", {
        className: "".concat(modalPrefixCls, "-item")
      }, /*#__PURE__*/React.createElement("div", {
        className: "".concat(modalPrefixCls, "-item-text")
      }, fieldValue.name))))));
    }
  }]);

  return CustomerSelector;
}(PureComponent || Component);

CustomerSelector.PropTypes = {
  field: PropTypes.object,
  // 字段数据
  layoutType: PropTypes.number,
  // 字段的布局类型：0 - 左右结构（默认），1 - 上下结构
  nullDisplayType: PropTypes.number,
  // 字段值为空时，显示的类型：0 - 显示'无'（默认），1 - 字段不显示
  commonPrefixCls: PropTypes.string,
  // 所有字段通用的 prefixCls
  labelWidth: PropTypes.number // label的宽度

};
CustomerSelector.defaultProps = {
  field: {}
};
export default CustomerSelector;

==> ehome-rcm-0.15.3.tgz: package/es/form-view/customFields/CustomerSelector/index.js <==
import "antd-mobile/es/modal/style";
import _Modal from "antd-mobile/es/modal";
import "antd-mobile/es/icon/style";
import _Icon from "antd-mobile/es/icon";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { PureComponent, Component } from 'react';
import PropTypes from 'prop-types';

var CustomerSelector =
/*#__PURE__*/
function (_ref) {
  _inherits(CustomerSelector, _ref);

  function CustomerSelector(props) {
    var _this;

    _classCallCheck(this, CustomerSelector);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(CustomerSelector).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "clickField", function () {
      var scrollTop = document.body.scrollTop || document.documentElement.scrollTop;
      var rootElement = document.getElementById('root'); // 使 root 脱离文档流

      rootElement.classList.add('dialog-open'); // 把脱离文档流的 root 拉上去，否则页面会回到顶部！

      rootElement.style.top = "".concat(-scrollTop, "px");

      _this.setState({
        visible: true,
        bodyScrollTop: scrollTop
      });
    });

    _defineProperty(_assertThisInitialized(_this), "closeModal", function (e) {
      e.stopPropagation();
      var bodyScrollTop = _this.state.bodyScrollTop;
      var rootElement = document.getElementById('root');
      rootElement.classList.remove('dialog-open'); // 滚回到老地方

      document.body.scrollTop = bodyScrollTop;
      document.documentElement.scrollTop = bodyScrollTop;

      _this.setState({
        visible: false
      });
    });

    _this.state = {
      visible: false
    };
    return _this;
  }

  _createClass(CustomerSelector, [{
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      // root回到文档流中
      var rootElement = document.getElementById('root');
      rootElement.classList.remove('dialog-open');
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          field = _this$props.field,
          layoutType = _this$props.layoutType,
          commonPrefixCls = _this$props.commonPrefixCls,
          labelWidth = _this$props.labelWidth,
          nullDisplayType = _this$props.nullDisplayType; // eslint-disable-next-line prefer-const

      var visible = this.state.visible;
      var fieldName = field.fieldName,
          _field$fieldValue = field.fieldValue,
          fieldValue = _field$fieldValue === void 0 ? '{}' : _field$fieldValue;
      fieldValue = JSON.parse(fieldValue);
      var prefixCls = 'eh-field-view-checkbox';
      var modalPrefixCls = "".concat(prefixCls, "-modal");
      prefixCls += layoutType === 0 ? '-hor' : '-ver';
      var hidden = nullDisplayType === 1 && !fieldValue.name.length;
      return hidden ? null : React.createElement("div", {
        className: prefixCls,
        onClick: !fieldValue.name ? null : this.clickField
      }, React.createElement("div", {
        className: "".concat(commonPrefixCls, "-name"),
        style: {
          width: labelWidth
        }
      }, fieldName), React.createElement("div", {
        className: "".concat(commonPrefixCls, "-value ").concat(prefixCls, "-value")
      }, React.createElement("div", {
        className: "".concat(prefixCls, "-info")
      }, React.createElement("div", {
        className: "".concat(prefixCls, "-info-text")
      }, fieldValue.name || '无'), React.createElement("i", {
        className: "".concat(prefixCls, "-icon eh-iconfont")
      }, "\uE773"))), React.createElement(_Modal, {
        popup: true,
        visible: visible,
        onClose: this.closeModal,
        animationType: "slide-up"
      }, React.createElement("div", {
        className: modalPrefixCls
      }, React.createElement("div", {
        className: "".concat(modalPrefixCls, "-header")
      }, React.createElement(_Icon, {
        type: "cross",
        onClick: this.closeModal
      }), React.createElement("span", {
        className: "".concat(modalPrefixCls, "-header-text")
      }, fieldName)), React.createElement("div", {
        className: "".concat(modalPrefixCls, "-content")
      }, React.createElement("div", {
        className: "".concat(modalPrefixCls, "-item")
      }, React.createElement("div", {
        className: "".concat(modalPrefixCls, "-item-text")
      }, fieldValue.name))))));
    }
  }]);

  return CustomerSelector;
}(PureComponent || Component);

CustomerSelector.PropTypes = {
  field: PropTypes.object,
  // 字段数据
  layoutType: PropTypes.number,
  // 字段的布局类型：0 - 左右结构（默认），1 - 上下结构
  nullDisplayType: PropTypes.number,
  // 字段值为空时，显示的类型：0 - 显示'无'（默认），1 - 字段不显示
  commonPrefixCls: PropTypes.string,
  // 所有字段通用的 prefixCls
  labelWidth: PropTypes.number // label的宽度

};
CustomerSelector.defaultProps = {
  field: {}
};
export default CustomerSelector;
